﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Bellwether.Utility
{
    public static class Setting
    {
        public static readonly List<string> PageNameList = new List<string>() { "大事記", "產品展示", "社會責任" };

        public static int BackHomeSec { get => settingJsonFile.BackHomeSec; }

        private static string dataDirectory = System.IO.Path.Combine(Directory.GetCurrentDirectory(), "Data");
        private static string settingJsonDataPath = System.IO.Path.Combine(dataDirectory, "setting.ini");

        private static SettingJson _settingJsonFile;
        private static SettingJson settingJsonFile
        {
            get
            {
                if (_settingJsonFile != null)
                    return _settingJsonFile;
                else
                {
                    AnalyzJsonFile();
                    return _settingJsonFile;
                }
            }
        }

        public static void Reload()
        {
            AnalyzJsonFile();
        }

        #region 解析 json
        public static T DeserializeFromJson<T>(string jsonStr)
        {
            T deserializedProduct = JsonConvert.DeserializeObject<T>(jsonStr);
            return deserializedProduct;
        }

        private static void AnalyzJsonFile()
        {
            string jsonResult;

            if (!File.Exists(settingJsonDataPath))
            {
                _settingJsonFile = new SettingJson()
                {
                    BackHomeSec = 60,
                };
            }
            else
            {
                using (StreamReader sr = new StreamReader(settingJsonDataPath))
                {
                    jsonResult = sr.ReadToEnd();
                }
                _settingJsonFile = DeserializeFromJson<SettingJson>(jsonResult);
            }
        }
        #endregion

    }

    public class SettingJson
    {
        public int BackHomeSec { get; set; }
    }
}
